<?php

/**
 * ReduxFramework Barebones Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */
if (!class_exists('Redux')) {
    return;
}

// This is your option name where all the Redux data is stored.
$servicer_opt_prefix = 'servicer_';
$servicer_opt_name = "servicer_options";
/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */
$servicer_theme = wp_get_theme('servicer'); // For use with some settings. Not necessary.

$servicer_args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => $servicer_opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $servicer_theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version' => $servicer_theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type' => 'submenu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true,
    // Show the sections below the admin menu item or not
    'menu_title' => esc_html__('Servicer Option', 'servicer'),
    'page_title' => esc_html__('Servicer Option', 'servicer'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key' => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => true,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar' => false,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => '',
    // Set a different name for your global variable other than the servicer_opt_name
    'dev_mode' => false,
    // Show the time the page took to load, etc
    'update_notice' => false,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
    // OPTIONAL -> Give you extra features
    'page_priority' => 65,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => '',
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => '_options',
    // Page slug used to denote the panel
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.
    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    'footer_credit'     => esc_html__( 'servicer - Personal Multipurpose Template. servicer is made to be used for business, corporate, creative agencies, and personal websites.', 'servicer' ),                 // Disable the footer credit of Redux. Please leave if you can help it.
    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.
    //'compiler'             => true,   
);

Redux::setArgs($servicer_opt_name, $servicer_args);
Redux::setSection($servicer_opt_name, array(
    'title' => esc_html__('Base theme option', 'servicer'),
    'id' => 'base_theme_option',
    'desc' => esc_html__('Chnage Base theme option here', 'servicer'),
    'icon' => 'el el-home',
    'fields' => array(
        array(
            'id' => $servicer_opt_prefix . 'preloader_on_off',
            'type' => 'switch',
            'title' => esc_html__('Preloader on off switch', 'servicer'),
            'default' => FALSE,
            'on' => esc_html__('Enable', 'servicer'),
            'off' => esc_html__('Disable', 'servicer'),
        ),
        array(
            'id' => $servicer_opt_prefix . 'back_to_top_on_off',
            'type' => 'switch',
            'title' => esc_html__('Back To Top on off switch', 'servicer'),
            'default' => FALSE,
            'on' => esc_html__('Enable', 'servicer'),
            'off' => esc_html__('Disable', 'servicer'),
        ),
    )
));
Redux::setSection($servicer_opt_name, array(
    'title' => esc_html__('Header option', 'servicer'),
    'id' => 'header_option',
    'desc' => esc_html__('Header option here', 'servicer'),
    'icon' => 'el el-home',
    'fields' => array(
        array(
            'id'       => $servicer_opt_prefix . 'header_style',
            'type'     => 'select',
            'title'    => esc_html__('Header style', 'servicer'), 
            'options'  => array(
                '1' => esc_html__('Header style one', 'servicer'),
                '2' => esc_html__('Header style two', 'servicer'),
            ),
            'default'  => false,
        ),
        array(
            'required' => array( $servicer_opt_prefix . 'header_style', '=', '2' ),
            'id' => $servicer_opt_prefix . 'menu_info_button',
            'type' => 'ace_editor',
            'title' => esc_html__('Svg Icon', 'servicer'),
            'subtitle' => esc_html__( 'Svg Icon Code: ', 'servicer' ),
        )
    )
));
Redux::setSection($servicer_opt_name, array(
    'subsection' => true,
    'title' => esc_html__('Header Top Bar option', 'servicer'),
    'id' => 'header_top_bar',
    'desc' => esc_html__('Chnage Header Top Bar here', 'servicer'),
    'icon' => 'el el-home',
    'fields' => array(
        array(
            'id' => $servicer_opt_prefix . 'top_bar_link',
            'type' => 'ace_editor',
            'title' => esc_html__('Top bar info link ', 'servicer'),
        ),
        array(
            'id' => $servicer_opt_prefix . 'top_bar_social_icon',
            'type' => 'ace_editor',
            'title' => esc_html__('Social icon', 'servicer'),
        ),
    )
));
Redux::setSection($servicer_opt_name, array(
    'title' => esc_html__('Breadcrumb area', 'servicer'),
    'id' => 'breadcrumb_area',
    'icon' => 'el el-home',
    'fields' => array(
        array(
            'id'       => $servicer_opt_prefix . 'blog_breadcrumb_style',
            'type'     => 'select',
            'title'    => esc_html__('Breadcrumb style', 'servicer'), 
            'options'  => array(
                '1' => esc_html__('Breadcrumb style one', 'servicer'),
                '2' => esc_html__('Breadcrumb style two', 'servicer'),
            ),
            'default'  => false,
        ),
        array(
            'id' => $servicer_opt_prefix . 'blog_breadcrumb_switch',
            'type' => 'switch',
            'title' => esc_html__('Blog breadcrumb on off switch', 'servicer'),
            'default' => FALSE,
            'on' => esc_html__('Enable', 'servicer'),
            'off' => esc_html__('Disable', 'servicer'),
        ),
        array(
            'required' => array( $servicer_opt_prefix . 'blog_breadcrumb_switch', '=', '1' ),
            'id'       => $servicer_opt_prefix . 'blog_breadcrumb_bg',
            'type'     => 'background', 
            'url'      => true,
            'title'    => esc_html__('Blog breadcrumb background', 'servicer'),
            'output'    => array(
                'background' => '.blog-breadcrumb', 
            )
        ),
        array(
            'required' => array( $servicer_opt_prefix . 'blog_breadcrumb_switch', '=', '1' ),
            'id' => $servicer_opt_prefix . 'blog_breadcrumb_content',
            'type' => 'text',
            'title' => esc_html__('Blog breadcrumb title', 'servicer'),
            'default' => esc_html__('OUR NEWS', 'servicer'),
        ),
        array(
            'id' => $servicer_opt_prefix . 'blog_single_breadcrumb_switch',
            'type' => 'switch',
            'title' => esc_html__('Blog Single breadcrumb on off switch', 'servicer'),
            'default' => FALSE,
            'on' => esc_html__('Enable', 'servicer'),
            'off' => esc_html__('Disable', 'servicer'),
        ),
        array(
            'required' => array( $servicer_opt_prefix . 'blog_single_breadcrumb_switch', '=', '1' ),
            'id'       => $servicer_opt_prefix . 'blog_single_breadcrumb_bg',
            'type'     => 'background', 
            'url'      => true,
            'title'    => esc_html__('Blog Single breadcrumb background', 'servicer'),
            'output'    => array(
                'background' => '.blog-single-breadcrumb', 
            )
        ),
        array(
            'required' => array( $servicer_opt_prefix . 'blog_single_breadcrumb_switch', '=', '1' ),
            'id' => $servicer_opt_prefix . 'blog_single_breadcrumb_content',
            'type' => 'text',
            'title' => esc_html__('Blog single breadcrumb title', 'servicer'),
            'default' => esc_html__('NEWS DETAILS', 'servicer'),
        ),
    )
));
Redux::setSection($servicer_opt_name, array(
    'title' => esc_html__('Blog Design option', 'servicer'),
    'id' => 'servicer_blog_area',
    'icon' => 'el el-home',
    'fields' => array(
        array(
            'id'       => $servicer_opt_prefix . 'blog_post_style',
            'type'     => 'select',
            'title'    => esc_html__('Blog style', 'servicer'), 
            'options'  => array(
                '1' => esc_html__('Blog style one', 'servicer'),
                '2' => esc_html__('Blog style two', 'servicer'),
            ),
            'default'  => false,
        ),
    )
));
Redux::setSection($servicer_opt_name, array(
    'title' => esc_html__('Footer option', 'servicer'),
    'id' => 'servicer_footer_area',
    'desc' => esc_html__('Chnage footer option here', 'servicer'),
    'icon' => 'el el-home',
    'fields' => array(
        array(
            'id'       => $servicer_opt_prefix . 'footer_top_elementor_widget',
            'type'     => 'select',
            'multi' => true,
            'title'    => esc_html__('Footer top Elementor widget', 'servicer'), 
            'options'  => servicer_elementor_library(),
        ),
        array(
            'id'       => $servicer_opt_prefix . 'footer_style',
            'type'     => 'select',
            'title'    => esc_html__('Footer style', 'servicer'), 
            'options'  => array(
                '1' => esc_html__('Footer style one', 'servicer'),
                '2' => esc_html__('Footer style two', 'servicer'),
            ),
            'default'  => false,
        ),
        array(
            'id' => $servicer_opt_prefix . 'footer_copyright',
            'type' => 'text',
            'title' => esc_html__('Copyright text', 'servicer'),
        ),
    )
));
